export default class AddContentSourceStepComponent {
    workflow: any;
    skipAdCookie: any;

    static config = {
        selector: 'addContentSourceStep',
        template: `
            <div layout="column">
            <div ng-if="!$ctrl.skipAdCookie" class="add-content-source-step__extension-promo">
                <mw-icon style="padding-top: 6px; margin-right: 18px; margin-left: 24px;" svg-icon="action:ic_info_outline_24px"></mw-icon>
                <div style="flex:1;">
                    {{$ctrl.AddContentTranslate.get('added-content__chrome-extension-card-information')}} <br>
                    <a class="mw-aqua" style="text-decoration: none;" href="https://chrome.google.com/webstore/detail/meltwater-extension/diifcbhhodecmbglfjdgpfdamonhlcbd" target="_blank">{{$ctrl.AddContentTranslate.get('added-content__chrome-extension-card--cta')}}</a>
                </div>
                <mw-icon class="add-content-source-step__hide-ad-button" ng-click="$ctrl.hideAd()" svg-icon="content:ic_clear_24px"></mw-icon>
             </div>
            <div>{{$ctrl.AddContentTranslate.get('add-content-workflow__source-step-label')}}</div>
                <md-input-container md-is-error="$ctrl.workflow.hasError('urls')" md-no-resize="true">
                    <textarea id="urlsTextArea" class="add-content-source-step__textarea-input" name="urls" ng-model="$ctrl.workflow.urls" ng-disabled="$ctrl.workflow.loading" wrap="off" rows="10" md-no-resize md-autofocus></textarea>
                    <div class="md-errors-spacer"></div>
                    <div ng-messages="$ctrl.workflow.validationErrors">
                        <div ng-message="urls">{{$ctrl.translateTooManyUrlsMessage()}}</div>
                    </div>
                </md-input-container>
            </div>
        `,
        controller: AddContentSourceStepComponent,
        bindings: {
            workflow: '<'
        }
    };

    /*@ngInject*/
    constructor(
        private AddContentTranslate,
        private AddContentTagService,
        private AddContentSearchService,
        private AddContentSplitService,
        private TokenService
    ) {

    }

    $onInit() {
        this.skipAdCookie = this.TokenService.getCookie('skipAdCookie');
        this.workflow.urls = this.workflow.urls || '';
        this.workflow.tags = [];
        this.workflow.searches = [];
        this.workflow.loadingTags = true;
        this.workflow.loadingSearches = true;
        this.workflow.isSearchFeatureEnable = false;
        this.AddContentTagService.getTagsAndFilterForPersonalization(this.workflow.userObject.activeCompanyId, this.workflow.userObject._id, this.workflow.preSelectedTags)
            .then(tagList => {
                this.workflow.tags = tagList.map(tag => {
                    return {
                        display: tag.name,
                        type: 'tag',
                        id: tag.id,
                        selected: this.workflow.preSelectedTags.indexOf(tag.name) >= 0
                    }
                })
                .sort((tagA, tagB) => {
                    if(tagA.display.toLowerCase() > tagB.display.toLowerCase()) {
                        return 1;
                    }
                    if(tagA.display.toLowerCase() < tagB.display.toLowerCase()) {
                        return -1;
                    }
                    return 0;
                });
                this.workflow.loadingTags = false;
            })
            .catch(error => {
                if (error) {
                    console.error('Failed to load tags from document modification service', error);
                }
            });

            this.AddContentSplitService.getFeatureToggle('ADD_CONTENT_ADD_TO_SEARCH', this.workflow.userObject.activeCompanyId)
            .then((isFeatureEnable)=>{
                if(isFeatureEnable){
                    this.workflow.isSearchFeatureEnable = true;
                    this.AddContentSearchService.getSearchesForCompany(this.workflow.userObject.activeCompanyId)
                    .then(searchList => {
                        this.workflow.searches = searchList.map(search => {
                            return {
                                display: search.name,
                                type: search.informationTypes.length? search.informationTypes[0] : '',
                                id: String(search.id),
                                selected: this.workflow.preSelectedSearches.indexOf(String(search.id)) >= 0
                            }
                        })
                        this.workflow.loadingSearches = false;
                    })
                    .catch(error => {
                        if (error) {
                            console.error('Failed to load searches', error);
                        }
                    })
                }
            })
            .catch(error => {
                if (error) {
                    console.error('Failed to load split setting', error);
                }
            })


    }
    hideAd = () => {
        const promoBanner = document.querySelector('.add-content-source-step__extension-promo');
        promoBanner.remove();
        document.cookie = "skipAdCookie= true; expires=Fri, 31 Dec 9999 23:59:59 GMT";

    }

    translateTooManyUrlsMessage = () =>  {
        return this.AddContentTranslate.get(this.workflow.validationErrors && this.workflow.validationErrors.urls || '', {
            limit: process.env.URL_LIMIT,
            numOver: this.workflow.documents && this.workflow.documents.length - process.env.URL_LIMIT || 0
        });
    }
}
