import './content-status-dialog.less';

export default class ContentStatusDialogComponent {
    workflow: any;

    static config = {
        selector: 'contentStatusDialog',
        template: `
            <mw-mini-modal-dialog class="content-status-dialog" layout="column" cancel="Cancel">
                <mw-modal-header>
                    <mw-modal-header-title>
                        {{::$ctrl.AddContentTranslate.get('add-content-workflow__content-status--dialog-title')}}
                        <mw-infotip class="content-status-dialog__info-tip" text-content="{{::$ctrl.AddContentTranslate.get('add-content-workflow__content-status--dialog-tooltip')}}"></mw-infotip>
                    </mw-modal-header-title>
                    <div class="content-status-dialog__header-subtitle">{{::$ctrl.AddContentTranslate.get('add-content-workflow__content-status--dialog-subtitle')}}</div>
                    <md-button 
                        class="mw-button mw-button--outlined content-status-dialog__refresh-button" 
                        ng-if="$ctrl.workflow.processingDocuments.length"
                        ng-disabled="$ctrl.workflow.loadingContentStatus" 
                        ng-click="$ctrl.refreshList()">
                        {{::$ctrl.AddContentTranslate.get('add-content-workflow__content-status--dialog-refresh-button')}}
                    </md-button>
                </mw-modal-header>
                <mw-modal-alert-message layout="column" ng-if="$ctrl.workflow.contentStatusError">
                    <div ng-if="$ctrl.workflow.contentStatusError">{{::$ctrl.AddContentTranslate.get('add-content-workflow__content-status--dialog-error')}}</div>
                </mw-modal-alert-message>
                <mw-modal-content flex>
                    <content-status-workflow workflow="$ctrl.workflow"></content-status-workflow>
                </mw-modal-content>
                <mw-modal-footer layout="row" layout-align="center center" flex>
                    <div flex=""></div>
                    <md-button ng-click="$ctrl.cancel()" class="mw-mini-modal__cancel-button mw-button">{{::$ctrl.AddContentTranslate.get('add-content-workflow__content-status--dialog-cancel')}}</md-button>
                    <md-button ng-click="$ctrl.ok()" class="mw-mini-modal__ok-button mw-button" ng-disabled="$ctrl.workflow.loadingContentStatus">
                        {{::$ctrl.AddContentTranslate.get('add-content-workflow__content-status--dialog-ok')}}
                    </md-button>
                </mw-modal-footer>
            </mw-mini-modal-dialog>
        `,
        controller: ContentStatusDialogComponent,
        bindings: {
            workflow: '<'
        },
    };

    /*@ngInject*/
    constructor(
        private $log,
        private $mdDialog,
        private AddContentTranslate,
        private ContentStatusService
    ) {
    }

    $onInit() {
        this.refreshList();
    }

    refreshList() {
        this.workflow.loadingContentStatus = true;
        this.workflow.contentStatusError = false;
        this.ContentStatusService.getContentStatus(this.workflow.processingDocuments)
            .then(documents => {
                this.workflow.processingDocuments = documents.filter(document => !document.contentIndexed);
                this.workflow.completedDocuments = this.workflow.completedDocuments.concat(documents.filter(document => document.contentIndexed));
            })
            .catch(error => {
                this.$log.error('Error checking content status', error);
                this.workflow.contentStatusError = true;
            })
            .finally(() => {
                this.workflow.loadingContentStatus = false;
            })
    }

    ok() {
        this.$mdDialog.hide(this.workflow.completedDocuments);
    }

    cancel() {
        this.$mdDialog.cancel();
    }
}
