export default class SearchSelectorDialogComponent {
    workflow: any;
    previouslySelected: any[];
    static config = {
        selector: 'searchSelectorDialog',
        template: `
            <mw-mini-modal-dialog class="add-content-input-selector mw-mini-modal-dialog" 
                layout="column" data="$ctrl.inputs" 
                title="Select input" 
                no-padding="true"
                ok="Select" 
                cancel="{{::$ctrl.AddContentTranslate.get('add-content-workflow__dialog—cancel--button')}}" 
                on-ok="$ctrl.handleOk($event)" 
                on-cancel="$ctrl.handleCancel($event)">
                    <mw-modal-header>
                        <mw-modal-header-title>{{::$ctrl.AddContentTranslate.get('mw-custom-scoring-input__select')}} ({{$ctrl.countSelected()}}/{{$ctrl.inputs.length}})</mw-modal-header-title>
                        <div flex=""></div>
                    </mw-modal-header>
                    <mw-modal-find>
                        <mw-find search="$ctrl.searchModel" debounce="300" placeholder="{{::$ctrl.AddContentTranslate.get('mw-collection-search__find')}}"></mw-find>
                    </mw-modal-find>
                    <mw-modal-content class="mw-menu-dialog mw-menu--has-find">

                        <mw-menu-subheader ng-show="$ctrl.searchModel.length && $ctrl.searchModel.length >= $ctrl.minSearchLength">
                            <span ng-if="$ctrl.filterCount() === 0">{{::$ctrl.AddContentTranslate.get('add-content-workflow__tags-modal--search-no-results')}}</span>
                            <span ng-if="$ctrl.filterCount() === 1">{{::$ctrl.AddContentTranslate.get('add-content-workflow__tags-modal--search-one-result')}}</span>
                            <span ng-if="$ctrl.filterCount() > 1">{{ ::$ctrl.AddContentTranslate.get('add-content-workflow__tags-modal--search-results', {numResults: $ctrl.filterCount()}) }} </span>
                        </mw-menu-subheader>
                        <mw-menu-item ng-repeat="input in filteredInputs = ($ctrl.inputs | filter: {display: $ctrl.searchModel})"
                                      aria-label="input.display"
                                      is-selected="input.selected"
                                      on-click="input.selected = !input.selected"
                                      type="multiselect">
                            {{input.display}}
                        </mw-menu-item>
                    </mw-modal-content>
            </mw-mini-modal-dialog>
        `,
        bindings: {
            inputs: '<',
            workflow: '<'
        },
        controller: SearchSelectorDialogComponent
    };

    searchModel: string;
    inputs: any;
    minSearchLength: number;

    /*@ngInject*/
    constructor(
        private $mdDialog,
        private $filter,
        private AddContentTranslate
    ) {
        this.searchModel = '';
        this.minSearchLength = 1;
    }

    $onInit() {
        // Store currently tag ids for diff when the dialog is closed
        this.previouslySelected = this.workflow.searches.filter(search => search.selected).map(search => search.id);
    }

    cancel() {
        this.$mdDialog.cancel();
    }

    handleOk(event) {
        this.$mdDialog.hide(this.inputs);
    };

    handleCancel(event) {
        // Unselect any tags selected during the current session
        this.workflow.searches = this.inputs.map(search => {
            return this.previouslySelected.includes(search.id)
                && {...search, selected: true}
                || {...search, selected: false};
        })

        this.$mdDialog.cancel();
    };

    countSelected() {
        return this.inputs.filter(search => search.selected).length;
    }

    filterCount() {
        return this.$filter('filter')(this.inputs, {display: this.searchModel}).length
    }

}
